@@ -1,10 +1,58 @@
-# Uses the HID API introduced in Mac OS X version 10.5
-# http://developer.apple.com/library/mac/#technotes/tn2007/tn2187.html
+# ----------------------------------------------------------------------------
+# pyglet
+# Copyright (c) 2006-2008 Alex Holkner
+# Copyright (c) 2008-2019 pyglet contributors
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+#
+#  * Redistributions of source code must retain the above copyright
+#    notice, this list of conditions and the following disclaimer.
+#  * Redistributions in binary form must reproduce the above copyright
+#    notice, this list of conditions and the following disclaimer in
+#    the documentation and/or other materials provided with the
+#    distribution.
+#  * Neither the name of pyglet nor the names of its
+#    contributors may be used to endorse or promote products
+#    derived from this software without specific prior written
+#    permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
+# ----------------------------------------------------------------------------
+from __future__ import print_function
+from __future__ import absolute_import
+from builtins import object
 
 import sys
-__LP64__ = (sys.maxsize > 2**32)
 
-from pyglet.libs.darwin.cocoapy import *
+from ctypes import cdll, util, CFUNCTYPE, byref, c_void_p
+from ctypes import c_int, c_ubyte, c_bool, c_uint32, c_uint64
+
+from .base import Device, Control, AbsoluteAxis, RelativeAxis, Button
+from .base import Joystick, AppleRemote
+from .base import DeviceExclusiveException
+
+from pyglet.libs.darwin.cocoapy import CFSTR, CFIndex, CFTypeID, known_cftypes
+from pyglet.libs.darwin.cocoapy import kCFRunLoopDefaultMode, CFAllocatorRef, cf
+from pyglet.libs.darwin.cocoapy import cfset_to_set, cftype_to_value, cfarray_to_list
+
+__LP64__ = (sys.maxsize > 2 ** 32)
+
+# Uses the HID API introduced in Mac OS X version 10.5
+# http://developer.apple.com/library/mac/#technotes/tn2007/tn2187.html
 
 # Load iokit framework
 iokit = cdll.LoadLibrary(util.find_library('IOKit'))
@@ -42,11 +90,11 @@ kHIDUsage_Csmr_VolumeIncrement = 0xE9
 kHIDUsage_Csmr_VolumeDecrement = 0xEA
 
 IOReturn = c_int  # IOReturn.h
-IOOptionBits = c_uint32   # IOTypes.h
+IOOptionBits = c_uint32  # IOTypes.h
 
 # IOHIDKeys.h
-IOHIDElementType = c_int 
-IOHIDElementCollectionType = c_int 
+IOHIDElementType = c_int
+IOHIDElementCollectionType = c_int
 if __LP64__:
     IOHIDElementCookie = c_uint32
 else:
@@ -188,23 +236,24 @@ iokit.IOHIDValueGetTypeID.restype = CFTypeID
 iokit.IOHIDValueGetTypeID.argtypes = []
 
 # Callback function types
-HIDManagerCallback = CFUNCTYPE(None, c_void_p, c_int, c_void_p, c_void_p)    
-HIDDeviceCallback = CFUNCTYPE(None, c_void_p, c_int, c_void_p)    
-HIDDeviceValueCallback = CFUNCTYPE(None, c_void_p, c_int, c_void_p, c_void_p)    
+HIDManagerCallback = CFUNCTYPE(None, c_void_p, c_int, c_void_p, c_void_p)
+HIDDeviceCallback = CFUNCTYPE(None, c_void_p, c_int, c_void_p)
+HIDDeviceValueCallback = CFUNCTYPE(None, c_void_p, c_int, c_void_p, c_void_p)
 
 ######################################################################
 # HID Class Wrappers
 
 # Lookup tables cache python objects for the devices and elements so that
 # we can avoid creating multiple wrapper objects for the same device.
-_device_lookup = {}  # IOHIDDeviceRef to python HIDDevice object  
-_element_lookup = {} # IOHIDElementRef to python HIDDeviceElement object
+_device_lookup = {}   # IOHIDDeviceRef to python HIDDevice object
+_element_lookup = {}  # IOHIDElementRef to python HIDDeviceElement object
 
-class HIDValue:
+
+class HIDValue(object):
     def __init__(self, valueRef):
         # Check that this is a valid IOHIDValue.
-        assert(valueRef)
-        assert(cf.CFGetTypeID(valueRef) == iokit.IOHIDValueGetTypeID())
+        assert valueRef
+        assert cf.CFGetTypeID(valueRef) == iokit.IOHIDValueGetTypeID()
         self.valueRef = valueRef
         self.timestamp = iokit.IOHIDValueGetTimeStamp(valueRef)
         self.length = iokit.IOHIDValueGetLength(valueRef)
@@ -218,7 +267,8 @@ class HIDValue:
         elementRef = c_void_p(iokit.IOHIDValueGetElement(valueRef))
         self.element = HIDDeviceElement.get_element(elementRef)
 
-class HIDDevice:
+
+class HIDDevice(object):
     @classmethod
     def get_device(cls, deviceRef):
         # deviceRef is a c_void_p pointing to an IOHIDDeviceRef
@@ -230,8 +280,8 @@ class HIDDevice:
 
     def __init__(self, deviceRef):
         # Check that we've got a valid IOHIDDevice.
-        assert(deviceRef)
-        assert(cf.CFGetTypeID(deviceRef) == iokit.IOHIDDeviceGetTypeID())
+        assert deviceRef
+        assert cf.CFGetTypeID(deviceRef) == iokit.IOHIDDeviceGetTypeID()
         _device_lookup[deviceRef.value] = self
         self.deviceRef = deviceRef
         # Set attributes from device properties.
@@ -247,15 +297,15 @@ class HIDDevice:
         self.primaryUsage = self.get_property("PrimaryUsage")
         self.primaryUsagePage = self.get_property("PrimaryUsagePage")
         # Populate self.elements with our device elements.
-        self.get_elements()        
+        self.elements = self._get_elements()
         # Set up callback functions.
         self.value_observers = set()
         self.removal_observers = set()
-        self.register_removal_callback()
-        self.register_input_value_callback()
+        self.removal_callback = self._register_removal_callback()
+        self.value_callback = self._register_input_value_callback()
 
     def dump_info(self):
-        for x in ('manufacturer', 'product', 'transport', 'vendorID', 'vendorIDSource', 'productID', 
+        for x in ('manufacturer', 'product', 'transport', 'vendorID', 'vendorIDSource', 'productID',
                   'versionNumber', 'serialNumber', 'locationID', 'primaryUsage', 'primaryUsagePage'):
             value = getattr(self, x)
             print(x + ":", value)
@@ -263,7 +313,7 @@ class HIDDevice:
     def unique_identifier(self):
         # Since we can't rely on the serial number, create our own identifier.
         # Can use this to find devices when they are plugged back in.
-        return (self.manufacturer, self.product, self.vendorID, self.productID, 
+        return (self.manufacturer, self.product, self.vendorID, self.productID,
                 self.versionNumber, self.primaryUsage, self.primaryUsagePage)
 
     def get_property(self, name):
@@ -271,46 +321,66 @@ class HIDDevice:
         cfvalue = c_void_p(iokit.IOHIDDeviceGetProperty(self.deviceRef, cfname))
         cf.CFRelease(cfname)
         return cftype_to_value(cfvalue)
-        
+
     def open(self, exclusive_mode=False):
-        if exclusive_mode: options = kIOHIDOptionsTypeSeizeDevice
-        else: options = kIOHIDOptionsTypeNone
+        if exclusive_mode:
+            options = kIOHIDOptionsTypeSeizeDevice
+        else:
+            options = kIOHIDOptionsTypeNone
         return bool(iokit.IOHIDDeviceOpen(self.deviceRef, options))
-    
+
     def close(self):
         return bool(iokit.IOHIDDeviceClose(self.deviceRef, kIOHIDOptionsTypeNone))
 
     def schedule_with_run_loop(self):
         iokit.IOHIDDeviceScheduleWithRunLoop(
-            self.deviceRef, 
-            c_void_p(cf.CFRunLoopGetCurrent()), 
+            self.deviceRef,
+            c_void_p(cf.CFRunLoopGetCurrent()),
             kCFRunLoopDefaultMode)
 
     def unschedule_from_run_loop(self):
         iokit.IOHIDDeviceUnscheduleFromRunLoop(
-            self.deviceRef, 
-            c_void_p(cf.CFRunLoopGetCurrent()), 
+            self.deviceRef,
+            c_void_p(cf.CFRunLoopGetCurrent()),
             kCFRunLoopDefaultMode)
 
-    def get_elements(self):
-        cfarray = c_void_p(iokit.IOHIDDeviceCopyMatchingElements(self.deviceRef, None, 0))
-        self.elements = cfarray_to_list(cfarray)
-        cf.CFRelease(cfarray)
+    def _get_elements(self):
+        try:
+            cfarray = c_void_p(iokit.IOHIDDeviceCopyMatchingElements(self.deviceRef, None, 0))
+            elements = cfarray_to_list(cfarray)
+            cf.CFRelease(cfarray)
+        except:
+            return []
+        return elements
 
     # Page and usage IDs are from the HID usage tables located at
     # http://www.usb.org/developers/devclass_docs/Hut1_12.pdf
     def conforms_to(self, page, usage):
         return bool(iokit.IOHIDDeviceConformsTo(self.deviceRef, page, usage))
-    def is_pointer(self):    return self.conforms_to(0x01, 0x01)
-    def is_mouse(self):      return self.conforms_to(0x01, 0x02)
-    def is_joystick(self):   return self.conforms_to(0x01, 0x04)
-    def is_gamepad(self):    return self.conforms_to(0x01, 0x05)
-    def is_keyboard(self):   return self.conforms_to(0x01, 0x06)
-    def is_keypad(self):     return self.conforms_to(0x01, 0x07)
-    def is_multi_axis(self): return self.conforms_to(0x01, 0x08)
+
+    def is_pointer(self):
+        return self.conforms_to(0x01, 0x01)
+
+    def is_mouse(self):
+        return self.conforms_to(0x01, 0x02)
+
+    def is_joystick(self):
+        return self.conforms_to(0x01, 0x04)
+
+    def is_gamepad(self):
+        return self.conforms_to(0x01, 0x05)
+
+    def is_keyboard(self):
+        return self.conforms_to(0x01, 0x06)
+
+    def is_keypad(self):
+        return self.conforms_to(0x01, 0x07)
+
+    def is_multi_axis(self):
+        return self.conforms_to(0x01, 0x08)
 
     def py_removal_callback(self, context, result, sender):
-        self = _device_lookup[sender] # avoid wonky python context issues
+        self = _device_lookup[sender]  # avoid wonky python context issues
         # Dispatch removal message to all observers.
         for x in self.removal_observers:
             if hasattr(x, 'device_removed'):
@@ -318,16 +388,14 @@ class HIDDevice:
         # Remove self from device lookup table.
         del _device_lookup[sender]
         # Remove device elements from lookup table.
-        for key, value in list(_element_lookup.items()):
+        for key, value in _element_lookup.items():
             if value in self.elements:
                 del _element_lookup[key]
 
-    def register_removal_callback(self):
-        self.removal_callback = HIDDeviceCallback(self.py_removal_callback)
-        iokit.IOHIDDeviceRegisterRemovalCallback(
-            self.deviceRef,
-            self.removal_callback,
-            None)
+    def _register_removal_callback(self):
+        removal_callback = HIDDeviceCallback(self.py_removal_callback)
+        iokit.IOHIDDeviceRegisterRemovalCallback(self.deviceRef, removal_callback, None)
+        return removal_callback
 
     def add_removal_observer(self, observer):
         self.removal_observers.add(observer)
@@ -339,12 +407,10 @@ class HIDDevice:
             if hasattr(x, 'device_value_changed'):
                 x.device_value_changed(self, v)
 
-    def register_input_value_callback(self):
-        self.value_callback = HIDDeviceValueCallback(self.py_value_callback)
-        iokit.IOHIDDeviceRegisterInputValueCallback(
-            self.deviceRef, 
-            self.value_callback,
-            None)
+    def _register_input_value_callback(self):
+        value_callback = HIDDeviceValueCallback(self.py_value_callback)
+        iokit.IOHIDDeviceRegisterInputValueCallback(self.deviceRef, value_callback, None)
+        return value_callback
 
     def add_value_observer(self, observer):
         self.value_observers.add(observer)
@@ -359,7 +425,7 @@ class HIDDevice:
             return None
 
 
-class HIDDeviceElement:
+class HIDDeviceElement(object):
     @classmethod
     def get_element(cls, elementRef):
         # elementRef is a c_void_p pointing to an IOHIDDeviceElementRef
@@ -371,8 +437,8 @@ class HIDDeviceElement:
 
     def __init__(self, elementRef):
         # Check that we've been passed a valid IOHIDElement.
-        assert(elementRef)
-        assert(cf.CFGetTypeID(elementRef) == iokit.IOHIDElementGetTypeID())
+        assert elementRef
+        assert cf.CFGetTypeID(elementRef) == iokit.IOHIDElementGetTypeID()
         _element_lookup[elementRef.value] = self
         self.elementRef = elementRef
         # Set element properties as attributes.
@@ -394,8 +460,8 @@ class HIDDeviceElement:
         self.name = cftype_to_value(iokit.IOHIDElementGetName(elementRef))
         self.reportID = iokit.IOHIDElementGetReportID(elementRef)
         self.reportSize = iokit.IOHIDElementGetReportSize(elementRef)
-        self.reportCount = iokit.IOHIDElementGetReportCount(elementRef)        
-        self.unit = iokit.IOHIDElementGetUnit(elementRef)        
+        self.reportCount = iokit.IOHIDElementGetReportCount(elementRef)
+        self.unit = iokit.IOHIDElementGetUnit(elementRef)
         self.unitExponent = iokit.IOHIDElementGetUnitExponent(elementRef)
         self.logicalMin = iokit.IOHIDElementGetLogicalMin(elementRef)
         self.logicalMax = iokit.IOHIDElementGetLogicalMax(elementRef)
@@ -403,45 +469,46 @@ class HIDDeviceElement:
         self.physicalMax = iokit.IOHIDElementGetPhysicalMax(elementRef)
 
 
-class HIDManager:
+class HIDManager(object):
     def __init__(self):
         # Create the HID Manager.
         self.managerRef = c_void_p(iokit.IOHIDManagerCreate(None, kIOHIDOptionsTypeNone))
-        assert(self.managerRef)
+        assert self.managerRef
         assert cf.CFGetTypeID(self.managerRef) == iokit.IOHIDManagerGetTypeID()
         self.schedule_with_run_loop()
         self.matching_observers = set()
-        self.register_matching_callback()
-        self.get_devices()
-        
-    def get_devices(self):
-        # Tell manager that we are willing to match *any* device.    
+        self.matching_callback = self._register_matching_callback()
+        self.devices = self._get_devices()
+
+    def _get_devices(self):
+        # Tell manager that we are willing to match *any* device.
         # (Alternatively, we could restrict by device usage, or usage page.)
         iokit.IOHIDManagerSetDeviceMatching(self.managerRef, None)
         # Copy the device set and convert it to python.
         cfset = c_void_p(iokit.IOHIDManagerCopyDevices(self.managerRef))
-        self.devices = cfset_to_set(cfset)
+        devices = cfset_to_set(cfset)
         cf.CFRelease(cfset)
+        return devices
 
     def open(self):
         iokit.IOHIDManagerOpen(self.managerRef, kIOHIDOptionsTypeNone)
 
     def close(self):
         iokit.IOHIDManagerClose(self.managerRef, kIOHIDOptionsTypeNone)
-        
+
     def schedule_with_run_loop(self):
         iokit.IOHIDManagerScheduleWithRunLoop(
-            self.managerRef, 
-            c_void_p(cf.CFRunLoopGetCurrent()), 
-            kCFRunLoopDefaultMode)
-        
-    def unschedule_from_run_loop(self):
-        iokit.IOHIDManagerUnscheduleFromRunLoop(
-            self.managerRef, 
-            c_void_p(cf.CFRunLoopGetCurrent()), 
+            self.managerRef,
+            c_void_p(cf.CFRunLoopGetCurrent()),
             kCFRunLoopDefaultMode)
 
-    def py_matching_callback(self, context, result, sender, device):
+    def unschedule_from_run_loop(self):
+        iokit.IOHIDManagerUnscheduleFromRunLoop(
+            self.managerRef,
+            c_void_p(cf.CFRunLoopGetCurrent()),
+            kCFRunLoopDefaultMode)
+
+    def _py_matching_callback(self, context, result, sender, device):
         d = HIDDevice.get_device(c_void_p(device))
         if d not in self.devices:
             self.devices.add(d)
@@ -449,27 +516,21 @@ class HIDManager:
                 if hasattr(x, 'device_discovered'):
                     x.device_discovered(d)
 
-    def register_matching_callback(self):
-        self.matching_callback = HIDManagerCallback(self.py_matching_callback)
-        iokit.IOHIDManagerRegisterDeviceMatchingCallback(
-            self.managerRef,
-            self.matching_callback,
-            None)
+    def _register_matching_callback(self):
+        matching_callback = HIDManagerCallback(self._py_matching_callback)
+        iokit.IOHIDManagerRegisterDeviceMatchingCallback(self.managerRef, matching_callback, None)
+        return matching_callback
+
 
 ######################################################################
-
 # Add conversion methods for IOHIDDevices and IOHIDDeviceElements
 # to the list of known types used by cftype_to_value.
 known_cftypes[iokit.IOHIDDeviceGetTypeID()] = HIDDevice.get_device
 known_cftypes[iokit.IOHIDElementGetTypeID()] = HIDDeviceElement.get_element
-
-
 ######################################################################
+
 # Pyglet interface to HID
 
-from .base import Device, Control, AbsoluteAxis, RelativeAxis, Button
-from .base import Joystick, AppleRemote
-from .base import DeviceExclusiveException
 
 _axis_names = {
     (0x01, 0x30): 'x',
@@ -501,6 +562,7 @@ _button_names = {
     (kHIDPage_Consumer, kHIDUsage_Csmr_VolumeDecrement): 'volume_down'
 }
 
+
 class PygletDevice(Device):
     def __init__(self, display, device, manager):
         super(PygletDevice, self).__init__(display, device.product)
@@ -512,7 +574,7 @@ class PygletDevice(Device):
         self._create_controls()
         self._is_open = False
         self._is_exclusive = False
-    
+
     def open(self, window=None, exclusive=False):
         super(PygletDevice, self).open(window, exclusive)
         self.device.open(exclusive)
@@ -544,14 +606,14 @@ class PygletDevice(Device):
             self.device.add_removal_observer(self)
             # Don't need to recreate controls since this is same device.
             # They are indexed by cookie, which is constant.
-            if self._is_open: 
+            if self._is_open:
                 self.device.open(self._is_exclusive)
                 self.device.schedule_with_run_loop()
-        
+
     def device_value_changed(self, hid_device, hid_value):
         # Called by device when input value changes.
         control = self._controls[hid_value.element.cookie]
-        control._set_value(hid_value.intvalue)
+        control.value = hid_value.intvalue
 
     def _create_controls(self):
         self._controls = {}
@@ -568,7 +630,7 @@ class PygletDevice(Device):
                 control = Button(name, raw_name)
             else:
                 continue
-            
+
             control._cookie = element.cookie
 
             self._controls[control._cookie] = control
@@ -580,21 +642,24 @@ class PygletDevice(Device):
                 control = self._controls[element.cookie]
                 hid_value = self.device.get_value(element)
                 if hid_value:
-                    control._set_value(hid_value.intvalue)
+                    control.value = hid_value.intvalue
+
 
 ######################################################################
 
 _manager = HIDManager()
 
+
 def get_devices(display=None):
-    return [ PygletDevice(display, device, _manager) for device in _manager.devices ]
+    return [PygletDevice(display, device, _manager) for device in _manager.devices]
+
 
 def get_joysticks(display=None):
-    return [ Joystick(PygletDevice(display, device, _manager)) for device in _manager.devices
-             if device.is_joystick() or device.is_gamepad() or device.is_multi_axis() ]
+    return [Joystick(PygletDevice(display, device, _manager)) for device in _manager.devices
+            if device.is_joystick() or device.is_gamepad() or device.is_multi_axis()]
+
 
 def get_apple_remote(display=None):
     for device in _manager.devices:
         if device.product == 'Apple IR':
             return AppleRemote(PygletDevice(display, device, _manager))
-
